You need to replace =org-activate-footnote-links= with this version without tooltips

#+begin_src emacs-lisp
  (defun my-org-activate-footnote-links (limit)
    "Add text properties for footnotes."
    (let ((fn (org-footnote-next-reference-or-definition limit)))
      (when fn
	(let* ((beg (nth 1 fn))
	       (end (nth 2 fn))
	       (label (car fn))
	       (referencep (/= (line-beginning-position) beg)))
	  (when (and referencep (nth 3 fn))
	    (save-excursion
	      (goto-char beg)
	      (search-forward (or label "fn:"))
	      (org-remove-flyspell-overlays-in beg (match-end 0))))
	  (add-text-properties beg end
			       (list 'mouse-face 'highlight
				     'keymap org-mouse-map
				     ;; 'help-echo
				     ;; (if referencep "Footnote reference"
				     ;;   "Footnote definition")
				     'font-lock-fontified t
				     'font-lock-multiline t
				     'face 'org-footnote))))))
#+end_src

Add tooltips to all the document footnote references with the content of each footnote
definition:

#+begin_src emacs-lisp
  (defun my-org-fn-make-tooltips ()
    "TODO"
    (interactive)
    (setq fncont nil)
    ;; You need to clone the buffer, in case the note is in a narrowed subtree:
    (when (get-buffer "fn-tooltip-tmp")
      (kill-buffer "fn-tooltip-tmp"))
    (with-current-buffer (current-buffer)
      (clone-indirect-buffer "fn-tooltip-tmp" nil))
    (set-buffer "fn-tooltip-tmp")
    (widen)
    (org-element-map (org-element-parse-buffer) 'footnote-reference
      (lambda (ref)
	(let* ((label (org-element-property :label ref)))
	  (org-element-map (org-element-parse-buffer) 'footnote-definition
	    (lambda (fn)
	      (when (string= (org-element-property :label fn) label)
		(let* ((from (org-element-property :contents-begin fn))
		       (to (org-element-property :contents-end fn))
		       (contents (buffer-substring-no-properties from to))
		       (cons (list label contents)))
		  (push cons fncont))))
	    nil nil)))
      nil nil)
    (save-excursion
      (goto-char (point-min))
      (while (re-search-forward org-footnote-re nil t)
	(when (eq (org-element-type (org-element-context)) 'footnote-reference)
	  (let* ((el (org-element-context))
		 (l (org-element-property :label el))
		 (b (org-element-property :begin el))
		 (e (org-element-property :end el))
		 (tooltip (cadr (assoc l fncont))))
	    (add-text-properties b e
				 `(help-echo
				   ,tooltip))))))
    (kill-buffer "fn-tooltip-tmp"))
#+end_src

The minor mode =my-org-fn-tooltip-mode= overrides =org-activate-footnote-links= and
evaluates =my-org-fn-make-tooltips= after:

- =org-mark-ring-goto=
- =org-edit-src-exit=

#+begin_src emacs-lisp
  (define-minor-mode my-org-fn-tooltip-mode
    "TODO"
    :lighter "fnt"
    :global nil
    (if my-org-fn-tooltip-mode
	(progn
	  (advice-add 'org-activate-footnote-links
		      :override
		      #'my-org-activate-footnote-links)
	  (advice-add 'org-mark-ring-goto
		      :after
		      #'my-org-fn-make-tooltips)
	  (advice-add 'org-edit-src-exit
		      :after
		      #'my-org-fn-make-tooltips))
      (advice-remove 'org-activate-footnote-links
		     #'my-org-activate-footnote-links)
      (advice-remove 'org-mark-ring-goto
		     #'my-org-fn-make-tooltips)
      (advice-remove 'org-edit-src-exit
		     #'my-org-fn-make-tooltips)))
#+end_src

#+begin_src emacs-lisp
;; (add-hook 'org-mode-hook #'my-org-fn-tooltip-mode)
#+end_src
